<template>
    <div v-loading.fullscreen.lock="markLoading" element-loading-background="rgba(255,255,255, 0.5)"
        element-loading-spinner="el-icon-loading" element-loading-text="数据加载中...">
        <el-dialog :before-close="handleClose" :class="[reqLoading ? 'dialog-box' : '', 'entry-dialog']"
            :close-on-click-modal="false" :destroy-on-close="true" :title="title" :visible="visible" top="6vh"
            width="80%">
            <div v-loading="reqLoading" element-loading-background="rgba(255, 255, 255, 1)"
                element-loading-spinner="el-icon-loading" element-loading-text="加载中...">
                <div class="form-title">
                    <div class="history-btn">
                        <RecordPopover v-if="addEditData.id" :id="addEditData.id"></RecordPopover>
                    </div>
                    <h1>市级部门改革情况填报表</h1>
                </div>
                <el-form ref="form" :model="addEditData" :rules="rules" label-position="left" label-width="0">
                    <el-form-item class="group-label" prop="groupName" v-if="title != '详情'" label="专项小组：">
                        <dict-select dictCode="zxxz" :hasDefaultOption="true" clearable v-model="addEditData.groupName"
                            style="width: 250px;" placeholder="请选择专项小组" />
                    </el-form-item>
                    <el-descriptions style="margin-bottom: 10px;" :column="1" :size="size" border
                        :labelStyle="{ width: '0.5%' }">
                        <el-descriptions-item v-if="title == '详情'" label="专项小组">
                            {{ addEditData.groupName }}
                        </el-descriptions-item>
                        <el-descriptions-item v-if="addEditData.approvalComments" label="驳回理由"
                            content-class-name="my-content">
                            {{ addEditData.approvalComments }}
                        </el-descriptions-item>
                    </el-descriptions>

                    <el-table :data="addEditData.situations" style="width: 100%" v-loading="tableLoading">
                        <el-table-column label="序号" type="index" width="60" align="center">
                        </el-table-column>
                        <el-table-column prop="indexName" label="指标名称" min-width="220" align="center">
                        </el-table-column>
                        <el-table-column label="指标类型" width="100" align="center">
                            <template v-slot="{ row }">
                                {{ getDictName('sj_zblx', row.indexType) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="indexUnit" label="单位" width="100" align="center">
                        </el-table-column>
                        <el-table-column prop="indexFinishValue" width="140" label="完成值" align="center">
                            <template v-slot="{ row, $index }">
                                <el-form-item v-if="title != '详情'" class="my-el-form-item" :prop="'situations.' +
                                    $index +
                                    '.indexFinishValue'
                                    " :rules="rules.indexFinishValue">
                                    <el-input v-model="row.indexFinishValue" placeholder="请输入指标完成值"></el-input>
                                </el-form-item>
                                <div v-else>{{ row.indexFinishValue }}</div>
                            </template>
                        </el-table-column>
                        <el-table-column prop="address" label="附件" width="500">
                            <template v-slot="{ row, $index }">
                                <el-link v-if="(title === '编辑' || title === '新增')" class="updload_btn" size="small"
                                    type="primary" @click="openUploade($index)">
                                    点击上传</el-link>
                                
                                <FileList v-if="(row.files && row.files.length) || (row.classified || row.classified > -1)" :fileList="row.files" :isDelete="title === '编辑' || title === '新增'"
                                    @changeFileList="changeFileList($event, $index)" :classified="row.classified === 1">
                                </FileList>
                                <div v-else>暂无附件</div>
                            </template>
                        </el-table-column>
                    </el-table>
                </el-form>
            </div>
            <span slot="footer" class="dialog-footer" :style="reqLoading ? 'position: relative;z-index: -1;' : ''">
                <template v-if="(title === '编辑' || title === '新增') && this.$route.name === 'ReformInformationEntry'">
                    <el-button type="primary" @click="handleSave(1)">保存并上报</el-button>
                    <el-button type="primary" plain @click="handleSave(0)">保存为草稿</el-button>
                </template>

                <template>
                    <template v-if="title === '审核'">
                        <el-button type="primary" @click="handleApprove">通过</el-button>
                        <el-button type="danger" @click="handleReject">驳回</el-button>
                    </template>
                </template>
                <el-button @click="visible = false">取 消</el-button>
            </span>
        </el-dialog>
        <UploadFile ref="uploadFile" class="upload-file" @setFileList="setFileList" @setAipher="setAipher" />
        <RejectInfoBlockDialog ref="RejectInfoBlockDialog" @sendRejectInfo="sendRejectInfo"></RejectInfoBlockDialog>
    </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import projectsAPI from '@/api/municipalReform'
import auditApi from '@/api/ReformSituation/reformAudit'
import FileList from '@/components/uploadFile/FileList.vue'
import UploadFile from '@/components/uploadFile/index.vue'
import RejectInfoBlockDialog from '@/components/dialog/RejectInfoBlockDialog.vue'
import api from '@/api/ReformSituation/municipal'

export default {
    name: 'projectsDialog',
    components: { RejectInfoBlockDialog, UploadFile, FileList },
    mixins: [TableMixin],
    data() {
        return {

            value: '',
            addEditData: {
                situations: [],
            },
            fileIndex: 0,
            visible: false,

            title: '新增',
            tableLoading: false,

            markLoading: false,
            reqLoading: false,
            year: '',
            rules: {
                groupName: [
                  { required: true, message: '请选择专项小组', trigger: 'change' },
                ],
                indexFinishValue: [
                    { required: true, message: '请输入指标完成值', trigger: 'change' },
                ]
            },
            basicList: {
                problem: [{ value: '' }],
                files: []
            },
            infoData: {
                status: 1,
                approvalComments: ''
            },
            groupNameOptions: [
                {
                    label: '党建统领体制改革专项小组',
                    value: '党建统领体制改革专项小组'
                },
                {
                    label: '经济体制改革专项小组',
                    value: '经济体制改革专项小组'
                },
                {
                    label: '社会民生领域改革专项小组',
                    value: '社会民生领域改革专项小组'
                },
                {
                    label: '民主与法制领域改革专项小组',
                    value: '民主与法制领域改革专项小组'
                },
                {
                    label: '文化体制改革专项小组',
                    value: '文化体制改革专项小组'
                },
                {
                    label: '平安法治领域改革专项小组',
                    value: '平安法治领域改革专项小组'
                },
                {
                    label: '其他',
                    value: '其他'
                }
            ]
        }
    },
    created() {
        let moment = require('moment')
        this.year = moment().format('YYYY')

    },
    mounted() { },
    methods: {
        // 弹层进入事件
        open(data, title) {
            this.visible = true
            this.title = title
            if (data && data.id) {
                //编辑
                this.getDetailsituations(data.id)
            } else {
                // 新增
                this.gteAddsituations()
            }
        },

        // 新增获取表格数据
        gteAddsituations() {
            this.reqLoading = true
            api.enableIndicator().then(res => {
                if (res.value) {
                    this.addEditData.situations = res.value.map(item => {
                        const { indexName, indexType, indexUnit, indexCode, id: indexId } = item
                        return {
                            indexName, indexType, indexUnit, indexCode, indexId, indexFinishValue: '', files: []
                        }
                    })
                }
                this.reqLoading = false
            })
        },
        // 编辑时获取表格数据
        getDetailsituations(id) {
            this.reqLoading = true
            api.getDetailById(id).then(res => {
                if (res) {
                    this.addEditData = res
                }
                this.reqLoading = false
            })
        },
        // -----附件相关-----
        openUploade(index) {
            this.fileIndex = index
            this.$refs.uploadFile.open('listOfMunicipalReforms')
        },
        setAipher() {
            this.$set(
                this.addEditData.situations[this.fileIndex],
                'classified',
                1
            )
        },
        setFileList(file) {
            file.id = file.response.fileId
            if (this.addEditData.situations[this.fileIndex].files) {
                this.addEditData.situations[this.fileIndex].files.push(file)
            } else {
                this.$set(
                    this.addEditData.situations[this.fileIndex],
                    'files',
                    []
                )
                this.addEditData.situations[this.fileIndex].files.push(file)
            }
            // this.$set(
            //     this.addEditData.situations[this.fileIndex],
            //     'classified',
            //     0
            // )
        },
        changeFileList(data, index) {
            this.addEditData.situations[index].files = data
        },
        // ---------------

        // 保存方法
        handleSave(status) {
            this.$refs['form'].validate((valid, object) => {
                if (valid) {
                    let msg = status ? '保存并上报' : '保存为草稿'
                    this.$confirm(`确认${msg}吗？`, this.$t('common.tips'), {
                        confirmButtonText: this.$t('common.confirm'),
                        cancelButtonText: this.$t('common.cancel'),
                        type: 'success'
                    })
                        .then(() => {
                            this.saveData(status, msg)
                        })
                        .catch(() => { })
                } else {
                    this.$message.error('请输入指标完成值')
                }
            })
        },

        // 保存数据
        saveData(status, msg, approvalComments) {
            this.markLoading = true
            let apiName = this.addEditData.id ? 'indexDataUpdate' : 'indexDataEntry'
            let data = JSON.parse(JSON.stringify(this.addEditData))
            data.status = status
            if (approvalComments) {
                data.approvalComments = approvalComments
            }
            api[apiName](data)
                .then(res => {
                    if (res.state) {
                        this.$message.success(`${msg}成功`)
                        this.$emit('getData')
                        this.handleClose()
                    }
                    this.markLoading = false
                })
                .catch(err => {
                    this.markLoading = false
                })
        },

        // 审核通过
        handleApprove() {
            let { name } = this.$route
            let status =
                name === 'DepartmentAudit'
                    ? 3
                    : name === 'SpecialGroupAudit'
                        ? 5
                        : 7
            this.$confirm(`确认审核通过?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'success'
            })
                .then(() => {
                    this.saveData(status, '审核通过')
                })
                .catch(() => { })
        },

        // 审核驳回
        handleReject() {
            this.$confirm(`确认驳回?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'error'
            })
                .then(() => {
                    this.$refs.RejectInfoBlockDialog.open()
                })
                .catch(() => { })
        },

        // 驳回提交数据
        sendRejectInfo(rejectInfo) {
            let { name } = this.$route
            let status =
                name === 'DepartmentAudit'
                    ? 2
                    : name === 'SpecialGroupAudit'
                        ? 4
                        : 6
            if (!rejectInfo) {
                this.saveLoading = false
                return
            }
            this.saveData(status, '审核驳回', rejectInfo)
        },

        // 清空数据
        handleClose() {
            this.addEditData = {
                situations: []
            }
            this.visible = false
            this.$nextTick(() => {
                this.$refs.form.clearValidate()
            })
        },
    }
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

/deep/.my-el-form-item {
    margin-bottom: 0 !important;
}
/deep/ .classified {
    color: #F56C6C;
}

.group-label {
    /deep/ .el-form-item__label {
        width: fit-content !important;
    }
}

/deep/.my-content {
    color: #F56C6C;
}

/deep/.record-style {
    .el-link--inner {
        display: block;
        min-width: 125px;
    }
}

.entry-dialog {
    /deep/ .el-dialog__body {
        height: 70vh;
    }
}

.form-title {
    position: relative;
    font-size: 16px;
    text-align: center;
    margin: 0 0 10px 0;
    padding-bottom: 10px;
    border-bottom: 1px solid #ebeef5;

    h1 {
        font-size: 16px;
        margin: 0;
    }

    .tab-btn {
        position: absolute;

        >span {
            cursor: pointer;
            font-size: 14px;
            margin-right: 10px;
            padding: 5px 0;

            &:hover {
                color: #2761ff;
                font-weight: bold;
            }
        }

        .active {
            position: relative;
            color: #2761ff;
            font-weight: bold;

            &::after {
                position: absolute;
                content: '';
                width: 100%;
                height: 2px;
                left: 0;
                bottom: 0;
                background: #2761ff;
            }
        }
    }

    .history-btn {
        position: absolute;
        width: 100px;
        height: 30px;
    }
}

.audit-status-opinion {
    position: absolute;
    top: 0;
    left: 5px;
    height: 100%;
    font-weight: bold;
    text-align: left;
}

.entry-input {
    width: 60px;

    /deep/ input {
        border: none;
        border-bottom: 1px solid #606266;
        border-radius: 0;
        height: 30px;
        width: 60px;
        text-align: center;
        padding: 0;
    }
}

.file-box {
    flex: 1;

    /deep/ .file-item {
        box-sizing: border-box;
        overflow: hidden;

        a {
            margin: 0;

            &:nth-child(2) {
                margin: 0 5px;
            }
        }
    }
}

.file-td {
    text-align: left;

    >div {
        display: flex;
        align-items: center;
        gap: 10px;
        font-size: 16px;

        a {
            margin-top: 5px;
            padding: 0 5px 0 5px;

            /deep/ .el-link--inner {
                font-size: 16px;
            }
        }

        .tip {
            font-size: 14px;
            color: #f56c6c;
        }
    }
}

.list-td {
    position: relative;
    text-align: left;
    padding-bottom: 0;

    >i {
        cursor: pointer;
        position: absolute;
        right: 50%;
        bottom: 0px;
        width: 60px;
        height: 20px;
        border: 1px solid #909399;
        line-height: 20px;
        text-align: center;
        border-top-left-radius: 5px;
        border-top-right-radius: 5px;
        border-bottom: 0;
        transform: translateX(-50%);
        font-weight: bolder;
        color: #909399;

        &:hover {
            color: #409eff;
            border-color: #409eff;
        }
    }
}

.table-title {
    font-size: 20px;
    font-weight: bold;
    padding-bottom: 10px;
    letter-spacing: 2px;
}

th,
td {
    height: 40px;
    padding: 5px;
    text-align: center;
    font-size: 15px;
}

td {
    font-size: 15px;
}

.text-list {
    margin-bottom: 20px;
    box-sizing: border-box;

    div {
        //width: 100%;
        //display: flex;
        //align-items: center;
        //justify-content: space-between;
        //padding: 5px;
        //box-sizing: border-box;
        //border-radius: 5px;
        //position: relative;

        .text-input {
            display: flex;
            align-items: center;
            flex: 1;
            gap: 5px;
            transition: all 0.3s;

            /deep/ .el-input__count {
                height: 13px;
                line-height: 13px;
            }

            /deep/ .el-textarea__inner {
                font-size: 15px;
            }

            /deep/ a {
                cursor: pointer;

                span {
                    width: 40px;
                    text-align: center;
                }

                width: fit-content;
            }
        }

        .text-value {
            width: 100%;
        }
    }
}

.inside-table {
    padding: 0;
    margin: 0;
    border-collapse: collapse;

    tr {
        border: none;
        border-bottom: 2px solid;

        th {
            border-right: 2px solid;

            /deep/ .el-button {
                border: 1px solid #dcdfe6;

                &:hover {
                    border-color: #bed0ff;
                }
            }
        }

        td {
            text-align: center;
            border: none;
            border-right: 2px solid;
        }

        > :last-child {
            border: none;
        }

        &:last-child {
            border: none;
        }
    }
}

/deep/ .file-item {
    margin: 0;
    padding: 5px;

    .file_name {
        max-width: 60%;
        height: auto;
        font-size: 16px !important;
    }
}

/deep/ .el-radio {
    margin-right: 0px;
}

.add-btn {
    font-weight: bold;
    cursor: pointer;
    color: $--color-primary;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/ .el-dialog__body {
    max-height: 75vh;
    overflow-y: auto;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

.timePicker {
    /deep/ .el-input__inner {
        width: 100px !important;
    }
}

//加载遮罩
/deep/ .el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/ .el-dialog__body {
        overflow: hidden;
    }
}

.my-el-table {
    /deep/ .el-form-item {
        margin-bottom: 0;
    }

    /deep/ .el-form-item.is-error {
        margin-bottom: 0;
    }
}

/deep/ .el-form-item__error {
    display: none;
}

.edit-li {}

.footer-btn {
    text-align: center;
    padding-top: 10px;
    border-top: 1px solid #ebeef5;
}
</style>